@@ -13,6 +13,7 @@ from .utils import (
     _get_archive_checksum,
     _get_or_create_resource_archive,
     generate_random_name,
+    get_mirror_by_name,
     make_name_by_path,
 )
 from ..interfaces import (
@@ -219,12 +220,16 @@ def _create_train_task(name: str,
                        algorithm: Algorithm,
                        project: Project,
                        hyperparams: dict,
+                       hyperparams_prefix: str="--",
+                       hyperparams_delimeter: str=" ",
                        mounts: Optional[Union[Dict[str, List[Resource]], Dict[str, Resource]]]=None,
                        algorithm_git_ref: Optional[str]=None,
                        resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
                        description: Optional[str]=None,			
                        entrypoint: Optional[str]=None,
                        output: Optional[str]=None,
+                       algorithm_dir: Optional[Union[str, Path]]=None,
+                       mirror_name: Optional[str]="QUICKSTART",
                        num_nodes: Optional[int]=1,
                        nproc_per_node: Optional[int]=1):
     resource_ids = []
@@ -243,14 +248,39 @@ def _create_train_task(name: str,
         algorithm_git_ref=algorithm_git_ref,
         files=resource_ids,
         train_params=json.dumps(train_params),
+        train_params_prefix=hyperparams_prefix,
+        train_params_delimeter=hyperparams_delimeter,
         resource_request=resource_request,
         description=description,
         num_nodes=num_nodes,
         nproc_per_node=nproc_per_node,
+        mirror_id=get_mirror_by_name(mirror_name).id,
     )
     if entrypoint is not None:
         train_task.entrypoint = entrypoint
     if output is not None:
+        output_path = Path(output)
+        output_path_ok = (
+            not output_path.is_absolute()
+            and '..' not in output_path.parts
+        )
+        if output_path_ok and algorithm_dir is not None:
+            output_path_joined = algorithm_dir / output_path
+            output_path_ok &= (
+                not output_path_joined.exists()
+                or (
+                    not output_path_joined.is_symlink()
+                    and output_path_joined.is_dir()
+                    and len([*output_path_joined.iterdir()]) == 0
+                )
+            )
+        if not output_path_ok:
+            raise AnyLearnException(
+                f'Invalid output path. A relative path without ".." required, '
+                f'and that path must be pointing at nothing or an empty '
+                f'directory (symlink not allowed). Got '
+                f'"{output_path_ok}".'
+            )
         train_task.output = output
     train_task.save()
     train_task.get_detail()
@@ -278,6 +308,8 @@ def quick_train(algorithm_id: Optional[str]=None,
                 resource_uploader: Optional[ResourceUploader]=None,
                 resource_polling: Union[float, int]=5,
                 hyperparams: dict={},
+                hyperparams_prefix: str="--",
+                hyperparams_delimeter: str=" ",
                 resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
                 quota_group_name: Optional[str]=None,
                 quota_group_request: Optional[Dict[str, int]]=None,
@@ -374,6 +406,11 @@ def quick_train(algorithm_id: Optional[str]=None,
         超参数字典中的键应为长参数名，如 :obj:`--param` ，并省略 :obj:`--` 部分传入。
         如需要标识类参数（flag），可将参数的值设为空字符串，如 :obj:`{'my-flag': ''}` ，等价于 :obj:`--my-flag` 传入训练命令。
         默认为空字典。
+    hyperparams_prefix : :obj:`str`, optional
+        训练超参数键前标识，可支持hydra特殊命令行传参格式的诸如 :obj:`+key1` 、 :obj:`++key2` 、 空前置 :obj:`key3` 等需求，
+        默认为 :obj:`--` 。
+    hyperparams_delimeter :obj:`str`, optional
+        训练超参数键值间的分隔符，默认为空格 :obj:` ` 。
     resource_request : :obj:`List[Dict[str, Dict[str, int]]]`, optional
         训练所需计算资源的请求。
         如未填，则使用Anylearn后端的 :obj:`default` 资源组中的默认资源套餐。
@@ -509,6 +546,8 @@ def quick_train(algorithm_id: Optional[str]=None,
         algorithm_git_ref=algorithm_git_ref or current_sha,
         project=project,
         hyperparams=hyperparams,
+        hyperparams_prefix=hyperparams_prefix,
+        hyperparams_delimeter=hyperparams_delimeter,
         mounts=mounts,
         resource_request=resource_request,
         description=task_description,
@@ -516,6 +555,8 @@ def quick_train(algorithm_id: Optional[str]=None,
         nproc_per_node=nproc_per_node,
         entrypoint=entrypoint,
         output=output,
+        algorithm_dir=algorithm_dir,
+        mirror_name=mirror_name,
     )
 
     DB().create_or_update_train_task(train_task=train_task)
