@@ -23,13 +23,23 @@ from anylearn.interfaces import TrainTask
 @click.group("run")
 def commands():
     """
-    Run training, evaluation or serving on remote Anylearn.
+    Run training or serving on remote Anylearn.
     """
     pass
 
 
 @commands.command()
 @click.argument('algorithm_name')
+@click.option(
+    '-e', '--entrypoint',
+    prompt=True,
+    help="Training entrypoint command of algorithm."
+)
+@click.option(
+    '-o', '--output',
+    prompt=True,
+    help="Training model saving path of algorithm."
+)
 @click.option(
     '-d', '--data',
     multiple=True,
@@ -93,6 +103,8 @@ def commands():
 @get_cmd_command()
 def training(
     algorithm_name: str,
+    entrypoint: str,
+    output: str,
     data: tuple,
     param: tuple,
     resource: tuple,
@@ -117,6 +129,8 @@ def training(
                                            resource_yaml)
     kwargs = {
         'algorithm_name': algorithm_name,
+        'entrypoint': entrypoint,
+        'output': output,
         'data_config': data_config,
         'param_config': param_config,
         'resource_config': resource_config,
@@ -226,6 +240,8 @@ def _get_resource_config(quota_group: str,
 
 def _do_train(config: AnylearnCliConfig,
               algorithm_name: str,
+              entrypoint: str,
+              output: str,
               data_config: Dict[str, str],
               param_config: Dict[str, str],
               resource_config: Dict[str, str]) -> TrainTask:
@@ -247,6 +263,8 @@ def _do_train(config: AnylearnCliConfig,
         'algorithm_dir': algo_dir,
         'hyperparams': param_config,
         'resource_request': resource_config,
+        'entrypoint': entrypoint,
+        'output': output,
     }
     if datasets:
         # TODO: support multiple datasets in quick_train
@@ -257,6 +275,8 @@ def _do_train(config: AnylearnCliConfig,
 
 
 def _dump_training_config(algorithm_name: str,
+                          entrypoint: str,
+                          output: str,
                           data_config: Dict[str, str],
                           param_config: Dict[str, str],
                           resource_config: Dict[str, str]) -> Path:
@@ -270,6 +290,8 @@ def _dump_training_config(algorithm_name: str,
     yaml.dump(
         {
             'algorithm_name': algorithm_name,
+            'entrypoint': entrypoint,
+            'output': output,
             'data_config': data_config,
             'param_config': param_config,
             'resource_config': resource_config,
@@ -297,15 +319,6 @@ def _load_training_config(training_config_path: str) -> dict:
     return training_config
 
 
-@commands.command()
-@get_cmd_command()
-def evaluation():
-    """
-    Coming soon.
-    """
-    pass
-
-
 @commands.command()
 @get_cmd_command()
 def serving():
